rfg_location: Bathroom locations
Description
Given a pair of coordinates (latitude and longitude), finds any nearby
bathrooms, subject to other parameters.
Usage
rfg_location(
lat,
lng,
accessible = FALSE,
unisex = FALSE,
verbose = TRUE,
tidy = FALSE
)
Arguments
accessible
If TRUE, only returns restrooms that meet the
Americans with Disability Act standards for accessibility.
Defaults to FALSE.
unisex
If TRUE, only returns unisex restrooms.
Defaults to FALSE.
verbose
If TRUE, prints query progress.
Defaults to TRUE.
tidy
If TRUE, makes USA state names more consistent. The internal
function focuses on correcting known errors and mistakes, if incorrect state
data is supplied that cannot be corrected. Defaults to FALSE.
Value
A tibble with details of any and all nearby refuge bathrooms.
Examples
Run this code# NOT RUN {
c <- rfg_location(lat = 39, lng = -75)
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab