rfg_search: Restroom record search
Description
Restroom record search
Usage
rfg_search(
search,
accessible = FALSE,
unisex = FALSE,
verbose = TRUE,
tidy = FALSE
)
Arguments
search
A string to search for. Note that the API does not accept
wildcard searchs, searches all fields in all available records, and only
returns exact (case-insensitive) whole-word matches.
accessible
If TRUE, only returns restrooms that meet the
Americans with Disability Act standards for accessibility.
Defaults to FALSE.
unisex
If TRUE, only returns unisex restrooms.
Defaults to FALSE.
verbose
If TRUE, prints query progress.
Defaults to TRUE.
tidy
If TRUE, makes USA state names more consistent. The internal
function focuses on correcting known errors and mistakes, if incorrect state
data is supplied that cannot be corrected. Defaults to FALSE.
Value
A tibble with all bathrooms matching your search request
Examples
Run this code# NOT RUN {
s <- rfg_search(search = "toronto")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab