If TRUE, only returns restrooms that meet the
Americans with Disability Act standards for accessibility.
Defaults to FALSE.
unisex
If TRUE, only returns unisex restrooms.
Defaults to FALSE.
verbose
If TRUE, prints query progress.
Defaults to TRUE.
tidy
If TRUE, makes USA state names more consistent. The internal
function focuses on correcting known errors and mistakes, if incorrect state
data is supplied that cannot be corrected. Defaults to FALSE.
Value
A tibble with details on all listed bathrooms.
Details
Note that the API does not standardise or validate the names of
states, cities, countries, etc, and so this data may need to be cleaned
and organised.